@@ -1,4 +1,3 @@
-#include <ctype.h>
 #include <stdio.h>
 #include <strings.h>
 
@@ -12,7 +11,7 @@ static void
 printsafe(const char *s)
 {
 	for (; *s; s++) {
-		if (iscntrl((unsigned char)*s))
+		if (ISCNTRL((unsigned char)*s))
 			continue;
 		else if (*s == '\\')
 			fputs("\\\\", stdout);
@@ -101,5 +100,8 @@ main(void)
 	xml_parse(&parser);
 	fputs("}\n", stdout);
 
+	checkfileerror(stdin, "<stdin>", 'r');
+	checkfileerror(stdout, "<stdout>", 'w');
+
 	return 0;
 }
