@@ -1,4 +1,3 @@
-#include <ctype.h>
 #include <stdio.h>
 #include <strings.h>
 
@@ -16,7 +15,7 @@ static void
 printvalue(const char *s)
 {
 	for (; *s; s++)
-		if (!iscntrl((unsigned char)*s))
+		if (!ISCNTRL((unsigned char)*s))
 			putchar(*s);
 }
 
@@ -136,5 +135,8 @@ main(int argc, char *argv[])
 	/* NOTE: getnext is defined in xml.h for inline optimization */
 	xml_parse(&parser);
 
+	checkfileerror(stdin, "<stdin>", 'r');
+	checkfileerror(stdout, "<stdout>", 'w');
+
 	return 0;
 }
